@@ -18,17 +18,18 @@
 
 #include <config.h>
 #include <locale.h>
-#include <ctype.h>
 #include <stdio.h>
 #include <stdlib.h>
 
+#include "progname.h"
+
 int
-main(int argc, char **argv)
+main (int argc, char **argv)
 {
   set_program_name (argv[0]);
-  if (setlocale (LC_ALL, argv[1]))
+  if (1 < argc && setlocale (LC_ALL, argv[1]))
     {
-      printf ("%d\n", MB_CUR_MAX);
+      printf ("%d\n", (int) MB_CUR_MAX);
       exit (EXIT_SUCCESS);
     }
 
